@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Callable, Iterator
+from typing import TYPE_CHECKING, Callable
 
 import pytest
 
@@ -9,6 +9,7 @@ from pipdeptree._models.package import Package
 from pipdeptree._render.text import render_text
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
     from unittest.mock import Mock
 
     from tests.our_types import MockGraph
@@ -247,7 +248,7 @@ def test_render_text(
 ) -> None:
     tree = example_dag.reverse() if reverse else example_dag
     encoding = "utf-8" if unicode else "ascii"
-    render_text(tree, max_depth=float("inf"), encoding=encoding, list_all=list_all, frozen=False)
+    render_text(tree, max_depth=float("inf"), encoding=encoding, list_all=list_all)
     captured = capsys.readouterr()
     assert "\n".join(expected_output).strip() == captured.out.strip()
 
@@ -436,7 +437,7 @@ def test_render_text_encoding(
     expected_output: list[str],
     example_dag: PackageDAG,
 ) -> None:
-    render_text(example_dag, max_depth=level, encoding=encoding, list_all=True, frozen=False)
+    render_text(example_dag, max_depth=level, encoding=encoding, list_all=True)
     captured = capsys.readouterr()
     assert "\n".join(expected_output).strip() == captured.out.strip()
 
@@ -445,7 +446,7 @@ def test_render_text_list_all_and_packages_options_used(
     capsys: pytest.CaptureFixture[str],
     mock_pkgs: Callable[[MockGraph], Iterator[Mock]],
 ) -> None:
-    graph: dict[tuple[str, str], list[tuple[str, list[tuple[str, str]]]]] = {
+    graph: MockGraph = {
         ("examplePy", "1.2.3"): [("hellopy", [(">=", "2.0.0")]), ("worldpy", [(">=", "0.0.2")])],
         ("HelloPy", "2.0.0"): [],
         ("worldpy", "0.0.2"): [],
@@ -457,7 +458,7 @@ def test_render_text_list_all_and_packages_options_used(
     # NOTE: Mimicking the --packages option being used here.
     package_dag = package_dag.filter_nodes(["examplePy"], None)
 
-    render_text(package_dag, max_depth=float("inf"), encoding="utf-8", list_all=True, frozen=False)
+    render_text(package_dag, max_depth=float("inf"), encoding="utf-8", list_all=True)
     captured = capsys.readouterr()
     expected_output = [
         "examplePy==1.2.3",
@@ -500,7 +501,7 @@ def test_render_text_with_license_info(
     capsys: pytest.CaptureFixture[str],
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
-    graph: dict[tuple[str, str], list[tuple[str, list[tuple[str, str]]]]] = {
+    graph: MockGraph = {
         ("a", "3.4.0"): [("c", [("==", "1.0.0")])],
         ("b", "2.3.1"): [],
         ("c", "1.0.0"): [],
@@ -549,7 +550,7 @@ def test_render_text_with_license_info_and_reversed_tree(
     capsys: pytest.CaptureFixture[str],
     monkeypatch: pytest.MonkeyPatch,
 ) -> None:
-    graph: dict[tuple[str, str], list[tuple[str, list[tuple[str, str]]]]] = {
+    graph: MockGraph = {
         ("a", "3.4.0"): [("b", [("==", "2.3.1")]), ("c", [("==", "1.0.0")])],
         ("b", "2.3.1"): [("c", [("==", "1.0.0")])],
         ("c", "1.0.0"): [],
